## 2.49.8 (2022-03-09)

Remove Python 2 support from some third-party distributions (#7466)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 2.49.7 (2022-01-30)

Reduce use of `Any` in equality methods (#7081)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2.49.6 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 2.49.5 (2022-01-07)

Update pyright (#6840)

## 2.49.3 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 2.49.2 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 2.49.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 2.49.0 (2021-09-19)

Update third-party package versions (#5996)

